searchData={"items":[{"type":"behaviour","title":"RuntimeCheck","doc":"A `GenServer` to run a set of system checks on application start up.\n\nThe process is normally run after the rest of the children in the supervisor, so processes like\n`Ecto`, `Oban`, and `FunWithFlags` are available.\nAdditionally, it is not actually kept in the supervision tree as `init/1` returns `:ignore` when\nthe checks succeed.","ref":"RuntimeCheck.html"},{"type":"behaviour","title":"Usage - RuntimeCheck","doc":"Define a module that uses `RuntimeCheck`:\n\n```elixir\ndefmodule MyApp.RuntimeChecks do\n  use RuntimeCheck\n\n  @impl true\n  def run? do\n    # Decide if checks should run. Maybe skip them during tests or if an env var is set.\n    true\n  end\n\n  @impl true\n  def checks do\n    # Return a list of checks. See `RuntimeCheck.DSL`.\n    [\n      check(:foo, fn ->\n        # Run function that should return :ok, {:ok, something}, :ignore or {:error, reason}\n        :ok\n      end),\n      check(:nested, [\n        check(:bar, fn -> :ignore end),\n        check(:baz, fn ->\n          if everything_ok() do\n            :ok\n          else\n            {:error, \"not everything is ok!\"}\n          end\n        end)\n      ]),\n      # If FunWithFlags is installed. Run nested checks only if the flag is enabled.\n      feature_check(:some_flag, [\n        app_var(:quzz_url :my_app, [:quzz, :url]),\n        env_var(\"QUZZ_API_KEY\")\n      ])\n    ]\n  end\nend\n```\n\nThen in `MyApp.application` add the worker\n\n```elixir\nchildren = [\n  # ...\n  MyApp.Repo,\n  MyAppWeb.Endpoint,\n  # ...\n  MyApp.RuntimeChecks\n]\n```\n\nThen when running the app, something like this will be logged:\n\n```text\n[info] [RuntimeCheck] starting...\n[info] [RuntimeCheck] foo: passed\n[info] [RuntimeCheck] nested:\n[warning] [RuntimeCheck] > bar: ignored\n[info] [RuntimeCheck] > baz: passed\n[info] [RuntimeCheck] nested: passed\n[info] [RuntimeCheck] some_flag:\n[info] [RuntimeCheck] > quzz_url: passed\n[info] [RuntimeCheck] > QUZZ_API_KEY: passed\n[info] [RuntimeCheck] some_flag: passed\n[info] [RuntimeCheck] done\n```\n\nOr if some checks fail:\n\n```text\n[info] [RuntimeCheck] starting...\n[info] [RuntimeCheck] foo: passed\n[info] [RuntimeCheck] nested:\n[warning] [RuntimeCheck] > bar: ignored\n[error] [RuntimeCheck] > baz: failed. Reason: \"not everything is ok!\"\n[error] [RuntimeCheck] nested: failed\n[info] [RuntimeCheck] some_flag:\n[info] [RuntimeCheck] > quzz_url: passed\n[info] [RuntimeCheck] > QUZZ_API_KEY: passed\n[info] [RuntimeCheck] some_flag: passed\n[error] [RuntimeCheck] some checks failed!\n** (Mix) Could not start application my_app: MyApp.Application.start(:normal, []) returned an error: shutdown: failed to start child: MyApp.RuntimeChecks\n    ** (EXIT) :runtime_check_failed\n```","ref":"RuntimeCheck.html#module-usage"},{"type":"behaviour","title":"Checks - RuntimeCheck","doc":"Each check is a `RuntimeCheck.Check` but normally, they are constructed using the functions\nin `RuntimeCheck.DSL`.","ref":"RuntimeCheck.html#module-checks"},{"type":"behaviour","title":"Feature flag checks - RuntimeCheck","doc":"If [fun_with_flags](https://github.com/tompave/fun_with_flags) is installed, a `feature_check`\nfunction will be available in the DSL. It allows running checks only if a feature flag is\nenabled.\n\nIf you add `fun_with_flags` after adding `runtime_check` make sure to recompile with\n`mix deps.compile --force runtime_check`.","ref":"RuntimeCheck.html#module-feature-flag-checks"},{"type":"behaviour","title":"Testing - RuntimeCheck","doc":"To test the checks you can run `MyApp.RuntimeChecks.run()`, which will run the checks in the\ncurrent process instead of starting a new one. You can pass `log: false` to disable logging.\n\n```elixir\nassert MyApp.RuntimeChecks.run(log: false) == {:ok, %{}}\n```\n\nSee `RuntimeCheck.run/2` for details on the return value.","ref":"RuntimeCheck.html#module-testing"},{"type":"callback","title":"RuntimeCheck.checks/0","doc":"A list of checks to run.","ref":"RuntimeCheck.html#c:checks/0"},{"type":"function","title":"RuntimeCheck.run/2","doc":"Runs the checks in the module.\n\nReturns `{:ok, ignored_map}` if checks pass. `ignored_map` is a a nested map of checks that\nwere ignored. Like `%{check1: :ignored, check2: %{subcheck1: :ignored}}`. The map is empty if\nno checks are ignored.\n\nIf at least one check fails, `{:error, map}` is returned. Where `map` is a nested map with\nignored and failed checks like\n\n```\n%{\n  check1: :ignored,\n  check2: \"failure reason\",\n  check3: %{\n    subcheck1: :ignored,\n    subcheck2: \"another reason\"\n  }\n}\n```\n\nBy default, the result will be logged, but it can be disabled by passing `log: false`.\n\nUse the module directly when starting in a supervisor tree. See the moduledocs for\n`RuntimeCheck`.","ref":"RuntimeCheck.html#run/2"},{"type":"callback","title":"RuntimeCheck.run?/0","doc":"Whether the checks should run on startup.","ref":"RuntimeCheck.html#c:run?/0"},{"type":"module","title":"RuntimeCheck.Check","doc":"Represents a system check.\n\n- name: The name of the check, an atom or string\n- checker: The function executed for the check, can be nil. It's as if the function returned `:ok`\n- nested_checks: A list of `Check` that are verified only if the `checker` returned `:ok`","ref":"RuntimeCheck.Check.html"},{"type":"type","title":"RuntimeCheck.Check.checker/0","doc":"","ref":"RuntimeCheck.Check.html#t:checker/0"},{"type":"type","title":"RuntimeCheck.Check.name/0","doc":"","ref":"RuntimeCheck.Check.html#t:name/0"},{"type":"function","title":"RuntimeCheck.Check.run/3","doc":"Runs the given check(s). Logs the result of each check if `log` is true.","ref":"RuntimeCheck.Check.html#run/3"},{"type":"type","title":"RuntimeCheck.Check.t/0","doc":"","ref":"RuntimeCheck.Check.html#t:t/0"},{"type":"module","title":"RuntimeCheck.DSL","doc":"Utility functions for creating checks.\n\nThe most basic functions are `check/2` and `check/3`.","ref":"RuntimeCheck.DSL.html"},{"type":"function","title":"RuntimeCheck.DSL.app_var/4","doc":"Creates an application variable check.\n\nThe third argument can be either an atom or a list of atoms.\nIf it's a list, the first element is used as key for Application.fetch_env/2 and the rest looked up using get_in, so the value should implement the Access protocol.\n\nThe check fails when the config is not present or results in a nil value.\n\nA list of invalid values can be passed as `opts` like `reject: [\"\"]`. If value of the variable\nis any of the list, the check fails.","ref":"RuntimeCheck.DSL.html#app_var/4"},{"type":"function","title":"RuntimeCheck.DSL.check/2","doc":"Creates a basic check.\n\nIt can be called using:\n`check(name, function)`\n`check(name, list)`\n`check(name, function, list)`\n\nWhen the second argument is a function with arity 0, it should return:\n- `:ok` or `{:ok, term()}` when the check passes. Nested checks are executed.\n- `:ignore` when the check is ignored, nested checks are ignored too.\n- `{:error, term()}` when the check fails. Nested checks are not executed.\n\nWhen the second or third argument is a list of checks, they are executed in order\nand only if the parent check initally passes.\n\nWhen the check has nested checks, the parent check only passes if all nested checks either pass or are ignored.\nWhen there are no nested checks, the check passes immediately.","ref":"RuntimeCheck.DSL.html#check/2"},{"type":"function","title":"RuntimeCheck.DSL.check/3","doc":"Creates a basic check with a function and a list of nested checks.\n\nSee `check/2` for more info.","ref":"RuntimeCheck.DSL.html#check/3"},{"type":"type","title":"RuntimeCheck.DSL.checker_or_list/0","doc":"","ref":"RuntimeCheck.DSL.html#t:checker_or_list/0"},{"type":"function","title":"RuntimeCheck.DSL.env_var/2","doc":"Creates a environment variable check.\n\nThe name of the environment variable is used as the name of the check.\nThe check fails when the variable is not present or when it's empty, unless `allow_empty: true` is given in the opts.\n\nThis check is intended to be used as a nested check, as always-required variables should be enfored in `config/runtime.exs`, not here.","ref":"RuntimeCheck.DSL.html#env_var/2"},{"type":"function","title":"RuntimeCheck.DSL.feature_check/2","doc":"Creates a feature flag check.\n\nThe name of the check is used as the feature flag name as well.\nThe function and/or nested checks are only executed if the feature is enabled using a boolean gate.\nIf not, the check is ignored.\n\nThe second and third argument behave like `check/2-3`.  See `check/2` for more info.","ref":"RuntimeCheck.DSL.html#feature_check/2"},{"type":"function","title":"RuntimeCheck.DSL.feature_check/3","doc":"Creates a feature flag check.\n\nSee `feature_check/2` for more info.","ref":"RuntimeCheck.DSL.html#feature_check/3"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.0 (2025-03-22) - Changelog","doc":"Initial version","ref":"changelog.html#0-1-0-2025-03-22"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}